@@ -40,7 +40,7 @@ class Agent(object):
     def __decrypt(self, v: str) -> Any:
         self.__check()
         hash, sk, v = v.split(" ")
-        if self.__verify(v, hash):
+        if self.__verify(v, b64d(hash)):
             return jl(self.__aesd(b64d(sk), v))
         raise Exception("credentials are tampered due to different hmac")
 
